<?php
/***************************************************************************
 *                        functions_profile_fields.php
 *                            -------------------
 *   author:                Brian Shields (alias Blankety Blank Man)
 *   email:                 blanketyblankman@gmail.com
 *   description:           Functions to be used by the Custom Profile Fields MOD
 *
 *
 ***************************************************************************/

/***************************************************************************
 *                               Version notes
 *                                 ---------
 *   1.0.1: February  1, 2006
 *   ------------------------
 *      - Improved the following of phpBB coding standards with { and } at places where
 *        they can be used
 *      - Began work on making this compatible with all dbms
 *
 *   1.0.0: December 27, 2005
 *   ------------------------
 *      - Current functions are fully featured, and used throughout MOD
 *      - Still lacks much power
 *
 *   0.0.1: December 25, 2005
 *   ------------------------
 *      - Predominantly a placeholder file
 ***************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

function get_fields($where_clause = '', $expect_multiple = true, $selection = '*')
{
  global $db;
  
  $sql = "SELECT $selection FROM " . PROFILE_FIELDS_TABLE . "
    $where_clause
    ORDER BY field_id ASC";
  if(!($result = $db->sql_query($sql)))
  {
    message_die(GENERAL_ERROR,'Could not select from ' . PROFILE_FIELDS_TABLE,'',__LINE__,__FILE__,$sql);
  }
  
  if($expect_multiple)
  {
    $profile_data = array();
    while($temp = $db->sql_fetchrow($result))
    {
      if(!empty($temp))
      {
        $profile_data[] = $temp;
      }
    }
  }
  else
  {
    $profile_data = $db->sql_fetchrow($result);
  }
  
  return $profile_data;
}

function text_to_column($text)
{
  $pattern = array("#&quot;#","#&amp;#","#&lt;#","#&gt;#");
  $replace = array('"','&','<','>');
  $text = preg_replace($pattern,$replace,$text);
  $pattern = "#[\s\*\$\(\)!\.,\?\/\\\[\]\{\};\:'\"&\^+=<>\|]#";
  $replace = "_";
  $text = preg_replace($pattern,$replace,$text);
  return strtolower($text);
}

function displayable_field_data($data, $type,$linkify=0)
{
  switch($type)
  {
    case TEXTAREA:
    	if ($linkify) {
	      $data = preg_replace('/((ftp|https?):\/\/[^ \t\n\r]+)/', '<a href="$1">$1</a>', $data);
	      $data = preg_replace('/<a href="([^"]+)[^a-zA-Z0-9\/]">/', '<a href="$1">', $data);
	      $data = preg_replace('/([^a-zA-Z0-9\/])<\/a>/', '</a>$1', $data);
	      $data = preg_replace('/">(ftp|https?):\/\/([^\/<]+)([^<]+)?<\/a>/', '">'."$name".'</a>', $data);
    	}
      return str_replace("\r\n","<br />",$data);
      break;
    case TEXT_FIELD:
    	if ($linkify) {
	      $data = preg_replace('/((ftp|https?):\/\/[^ \t\n\r]+)/', '<a href="$1">$1</a>', $data);
	      $data = preg_replace('/<a href="([^"]+)[^a-zA-Z0-9\/]">/', '<a href="$1">', $data);
	      $data = preg_replace('/([^a-zA-Z0-9\/])<\/a>/', '</a>$1', $data);
	      $data = preg_replace('/">(ftp|https?):\/\/([^\/<]+)([^<]+)?<\/a>/', '">'."$name".'</a>', $data);
    	}
    	return $data;
      break;
    case RADIO:
      return $data;
      break;
    case CHECKBOX:
      $data_list = explode(',',$data);
      $tmp = array();
      foreach($data_list as $val)
        if(!empty($val))
          $tmp[] = $val;
      $data_list = $tmp;
      $list_size = count($data_list);
      $data = str_replace(',',', ',$data);
      
      if($list_size == 0)
      {
        return '';
      }
      elseif($list_size == 1)
      {
        return $data_list[0];
      }
      else
      {
        return substr($data,0,strrpos($data,', ')) . ' and ' . substr($data,strrpos($data,', ') + 2);
      }
  }
}
?>
